==> xmule-1.9.0.tar.bz2: xmule-1.9.0/src/types.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef TYPES_H
#define TYPES_H

#include <stdint.h>                         // Needed for uint64_t

typedef unsigned char		int8;
typedef unsigned short		int16;
typedef unsigned int		int32;
typedef unsigned char		uint8;
typedef  signed  char		sint8;
typedef unsigned short		uint16;
typedef  signed  short		sint16;
typedef unsigned int		uint32;
typedef  signed  int		sint32;
typedef int64_t	int64;
typedef uint64_t uint64;
typedef int64_t sint64;
typedef unsigned long		ulong;
typedef unsigned short		ushort;
typedef unsigned char		uchar;
template <typename type> void safe_delete(type &del) { if(del) { delete del; del=0; } }

#endif

==> xmule-1.10.0.tar.bz2: xmule-1.10.0/src/types.h <==
// This file is a part of the xMule Project.
//
// Copyright (c) 2004 Theodore R. Smith (hopeseekr@xmule.ws / http://www.xmule.ws/)
// DSA-1024 Fingerprint: 10A0 6372 9092 85A2 BB7F 907B CB8B 654B E33B F1ED
//
// This program is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either
// version 2 of the License, or (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef TYPES_H
#define TYPES_H
/*
typedef unsigned char		int8_t;
typedef unsigned short		int16_t;
typedef unsigned int		int32_t;
typedef unsigned char		uint8_t;
typedef  signed  char		int8_t;
typedef unsigned short		uint16_t;
typedef  signed  short		int16_t;
typedef unsigned int		uint32_t;
typedef  signed  int		int32_t;
typedef unsigned long long	int64_t;
typedef unsigned long long	uint64_t;
typedef signed long long	int64_t;
typedef unsigned long		uint32_t;
typedef unsigned short		uint16_t;
typedef unsigned char		unsigned char;*/
template <typename type> void safe_delete(type &del) { if(del) { delete del; del=0; } }

#endif
